@@ -1,4 +1,5 @@
 
+import math
 import os
 import shutil
 import time
@@ -17,6 +18,7 @@ class CommonDump():
         return self._file_struct_pyc
 
     def __init__(self):
+        self.total_handled_count = 0
         self._file_struct_pyc: PackageStruct = None
         self.action_dispatch = {
             'nofile': self.handle_nofile,
@@ -49,12 +51,14 @@ class CommonDump():
         new_file = f'{output_dir}{os.path.sep}{target_file}'
         shutil.copy(target_file, new_file)
         PackageStruct.decompile_pyc(new_file)
+        return f'pyc file handled:{new_file}'
 
     def handle_arch_file(self, target_file: str):
         output_dir = self.build_output_dir()
         arch = get_archive(target_file)
         self.extract_arch(arch, output_dir)
         self.file_struct_pyc.progress_check()
+        return f'{self.total_handled_count} arch file(s) handled.'
 
     @staticmethod
     def load_plugins(plugin):
@@ -67,14 +71,26 @@ class CommonDump():
             return [p, n]
         plugin = [filter_plugin(x) for x in plugin]
         plugin_paths = [x[1] for x in plugin if x]
-        print('plugins loaded with', [x[0] for x in plugin if x])
+        print('[*] plugins loaded with', [x[0] for x in plugin if x])
         [setattr(configuration, x, True) for x in plugin_paths]
 
         if configuration.plugin_decompiler_enable_uncompyle6 and configuration.decompile_file == None:
             print('[!] attention! when use uncompyle6 , you should use --decompile_file specified which file to decompile for faster task.')
-            time.sleep(10)
+            time.sleep(3)
+
+    def statistics_status(self, is_end: bool = False):
+        if is_end:
+            g = self.global_start_time
+            g = time.strftime(g)
+            cost = time.time() - g
+            cost = math.ceil(cost*1e3)
+            print(f'[+] completed,cost {cost}ms',
+                  f'start at {g}', f'with result:{self.result}')
+            return
+        self.global_start_time = time.time()
 
     def main(self, target_file: str, output_directory: str, thread: int = 0, timeout: int = 10, target_file_type: str = None, session_timeout: int = 120, plugin: List = [], decompile_file: List = None, **args):
+        self.statistics_status()
         configuration.thread_count = thread  # thread
         configuration.thread_timeout = timeout
         configuration.thread_output_directory = output_directory
@@ -94,13 +110,14 @@ class CommonDump():
         file_type = target_file_type or self.get_filetype(target_file)
         dispatch_to = self.action_map.get(file_type, None)
         if not dispatch_to in self.action_dispatch:
-            result = f'unkonwn file-type:{file_type}->{dispatch_to}'
+            self.result = f'unkonwn file-type:{file_type}->{dispatch_to}'
         else:
             print(f'[*] start dump target file.')
             time.sleep(3)
-            result = self.action_dispatch[dispatch_to](target_file)
-        print('[+] completed', result)
-        return result
+            self.result = self.action_dispatch[dispatch_to](target_file)
+
+        self.statistics_status(True)
+        return self.result
 
     @staticmethod
     def get_filetype(filepath: str):
@@ -128,6 +145,7 @@ class CommonDump():
                 lambda x: not x.startswith('_'), list(children_package))
         else:
             children_package = children_package.data
+        self.total_handled_count += len(children_package)
         for package in children_package:
             p = PackageDescription(package, arch, current_directory)
             self.file_struct_pyc.add(p)
